##  Creating a Fresh Survey Run from a Finished Survey
Instead of designing a new survey from scratch, you can always reuse, modify, or extend a previously used survey questionnaire by creating a fresh survey run from a finished survey. This allows you to keep collected data up-to-date, capture new insights, and reflect updated conditions or feedback.
When creating a fresh survey run, you can adjust the scope, design, recipients, or other settings via the tabs at the top to ensure the survey configurations are up-to-date and aligned with your current needs.
To create a fresh survey run, do the following:
  1. Select the finished survey from the Manage Surveys section.
  2. If needed, adjust the scope, design, recipients, or other settings by navigating through the tabs at the top.
  3. In the Share tab, click Go Live.


YesNo
Send
